==> 1.0.2.tar.gz: android/src/main/java/co/hyperverge/hypersnapsdk/hypersnapsdk_flutter/FLHVQRScanCapture.java <==
package co.hyperverge.hypersnapsdk.hypersnapsdk_flutter;

import android.content.Context;
import android.os.Build;
import android.util.Log;

import androidx.annotation.RequiresApi;

import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Objects;

import co.hyperverge.hypersnapsdk.activities.HVQrScannerActivity;
import co.hyperverge.hypersnapsdk.listeners.QRScannerCompletionHandler;
import co.hyperverge.hypersnapsdk.objects.HVError;

public class FLHVQRScanCapture {

    static final String QR_SCAN_CAPTURE_START = "qrScanCaptureStart";
    private static final String TAG = FLHVQRScanCapture.class.getSimpleName();
    private boolean hasBeenCalled;

    public void start(Context context, final QRScannerCompletionHandler callback) {
        hasBeenCalled = false;
        HVQrScannerActivity.start(context, new QRScannerCompletionHandler() {
            @RequiresApi(api = Build.VERSION_CODES.KITKAT)
            @Override
            public void onResult(HVError error, JSONObject result) {
                callback.onResult(error, result);
            }
        });
    }

    @RequiresApi(api = Build.VERSION_CODES.KITKAT)
    public List<Map<String, Object>> getALFromOnResultQRScan(HVError error, JSONObject result) {
        ArrayList<Map<String, Object>> arrayList = new ArrayList<>();

        Map<String, Object> errorObj = new HashMap<>();
        Map<String, Object> resultsObj = new HashMap<>();
        try {
            if (error != null) {
                errorObj.put("errorCode", error.getErrorCode());
                errorObj.put("errorMessage", error.getErrorMessage());
                if (!hasBeenCalled) {
                    hasBeenCalled = true;
                }
            } else if (result != null) {
                Iterator<?> keys = result.keys();
                while (keys.hasNext()) {
                    String key = (String) keys.next();
                    try {
                        if (result.get(key) instanceof String) {
                            resultsObj.put(key, result.get(key));
                        } else if (result.get(key) instanceof JSONObject) {
                            resultsObj.put(key, result.get(key).toString());
                        }
                    } catch (Exception e) {
                        Log.e(TAG, Objects.requireNonNull(e.getMessage()));
                    }
                }
            }
            if (!hasBeenCalled) {
                hasBeenCalled = true;
            }

        } catch (Exception e) {
            Log.e(TAG, Objects.requireNonNull(e.getMessage()));
        }
        arrayList.add(errorObj);
        arrayList.add(resultsObj);
        return arrayList;
    }
}

==> 1.1.0.tar.gz: android/src/main/java/co/hyperverge/hypersnapsdk/hypersnapsdk_flutter/FLHVQRScanCapture.java <==
package co.hyperverge.hypersnapsdk.hypersnapsdk_flutter;

import android.content.Context;
import android.os.Build;
import android.util.Log;

import androidx.annotation.RequiresApi;

import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Objects;

import co.hyperverge.hypersnapsdk.activities.HVQrScannerActivity;
import co.hyperverge.hypersnapsdk.listeners.QRScannerCompletionHandler;
import co.hyperverge.hypersnapsdk.objects.HVError;

public class FLHVQRScanCapture {

    static final String QR_SCAN_CAPTURE_START = "qrScanCaptureStart";
    private static final String TAG = FLHVQRScanCapture.class.getSimpleName();
    private boolean hasBeenCalled;

    public void start(Context context, final QRScannerCompletionHandler callback) {
        hasBeenCalled = false;
        HVQrScannerActivity.start(context, new QRScannerCompletionHandler() {
            @RequiresApi(api = Build.VERSION_CODES.KITKAT)
            @Override
            public void onResult(HVError error, JSONObject result) {
                callback.onResult(error, result);
            }
        });
    }

    @RequiresApi(api = Build.VERSION_CODES.KITKAT)
    public List<Map<String, Object>> getALFromOnResultQRScan(HVError error, JSONObject result) {
        ArrayList<Map<String, Object>> arrayList = new ArrayList<>();

        Map<String, Object> errorObj = new HashMap<>();
        Map<String, Object> resultsObj = new HashMap<>();
        try {
            if (error != null) {
                errorObj.put("errorCode", error.getErrorCode());
                errorObj.put("errorMessage", error.getErrorMessage());
                if (!hasBeenCalled) {
                    hasBeenCalled = true;
                }
            } if (result != null) {
                Iterator<?> keys = result.keys();
                while (keys.hasNext()) {
                    String key = (String) keys.next();
                    try {
                        if (result.get(key) instanceof String) {
                            resultsObj.put(key, result.get(key));
                        } else if (result.get(key) instanceof JSONObject) {
                            resultsObj.put(key, result.get(key).toString());
                        }
                    } catch (Exception e) {
                        Log.e(TAG, Objects.requireNonNull(e.getMessage()));
                    }
                }
            }
            if (!hasBeenCalled) {
                hasBeenCalled = true;
            }

        } catch (Exception e) {
            Log.e(TAG, Objects.requireNonNull(e.getMessage()));
        }
        arrayList.add(errorObj);
        arrayList.add(resultsObj);
        return arrayList;
    }
}
